"""auxi.modelling.business Package

The purpose of this package is to provide common classes and functions for the rest of the auxi.modelling.business namespace"""

__version__ = "0.1.0"

import auxi.modelling.accounting.financial
import auxi.modelling.accounting.stock
from auxi.modelling.business._business import *